=======
History
=======

0.0.2 (2024-01-24)
------------------

* No longer iterate over pocket and publication status for much quicker query times.

0.0.1 (2024-01-24)
------------------

* First release on PyPI.
